/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others. All rights reserved. This
 * program and the accompanying materials are made available under the terms of
 * the Eclipse Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.equinox.p2.eclipsecon.actions.test;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.eclipse.equinox.internal.p2.engine.ActionManager;
import org.eclipse.equinox.internal.p2.engine.InstructionParser;
import org.eclipse.equinox.internal.p2.engine.ParameterizedProvisioningAction;
import org.eclipse.equinox.internal.p2.touchpoint.eclipse.EclipseTouchpoint;
import org.eclipse.equinox.internal.provisional.frameworkadmin.Manipulator;
import org.eclipse.equinox.internal.provisional.p2.core.Version;
import org.eclipse.equinox.internal.provisional.p2.engine.IProfile;
import org.eclipse.equinox.internal.provisional.p2.engine.InstallableUnitOperand;
import org.eclipse.equinox.internal.provisional.p2.engine.ProvisioningAction;
import org.eclipse.equinox.internal.provisional.p2.metadata.ITouchpointType;
import org.eclipse.equinox.internal.provisional.p2.metadata.MetadataFactory;
import org.eclipse.equinox.p2.eclipsecon.actions.SampleEclipseAction;
import org.eclipse.equinox.p2.eclipsecon.actions.SampleSystemOutAction;
import org.eclipse.equinox.p2.tests.AbstractProvisioningTest;

public class SampleEclipseActionTest extends AbstractProvisioningTest {
	public void testParseAction() {
		InstructionParser parser = new InstructionParser(new ActionManager());
		ProvisioningAction[] actions = parser.parseActions(MetadataFactory.createTouchpointInstruction("sample.EclipseAction()", null), null);
		assertEquals(1, actions.length);
		ProvisioningAction action = actions[0];
		if (action instanceof ParameterizedProvisioningAction)
			action = ((ParameterizedProvisioningAction)action).getAction();		
		assertEquals(action.getClass(), SampleEclipseAction.class);
	}
	
	public void testParseActionWithImports() {
		InstructionParser parser = new InstructionParser(new ActionManager());
		ProvisioningAction[] actions = parser.parseActions(MetadataFactory.createTouchpointInstruction("EclipseAction()", "sample.EclipseAction"), null);
		assertEquals(1, actions.length);
		ProvisioningAction action = actions[0];
		if (action instanceof ParameterizedProvisioningAction)
			action = ((ParameterizedProvisioningAction)action).getAction();		
		assertEquals(action.getClass(), SampleEclipseAction.class);
	}
	

	public void testParseActionUsingTouchpointQualification() {
		ITouchpointType TOUCHPOINT_TYPE = MetadataFactory.createTouchpointType("org.eclipse.equinox.p2.osgi", new Version("1.0")); //$NON-NLS-1$
		
		InstructionParser parser = new InstructionParser(new ActionManager());
		ProvisioningAction[] actions = parser.parseActions(MetadataFactory.createTouchpointInstruction("TouchpointAliasSample()", null), TOUCHPOINT_TYPE);
		assertEquals(1, actions.length);
		ProvisioningAction action = actions[0];
		if (action instanceof ParameterizedProvisioningAction)
			action = ((ParameterizedProvisioningAction)action).getAction();		
		assertEquals(action.getClass(), SampleEclipseAction.class);
	}
	
	public void testExecuteUndo() {
		Map parameters = new HashMap();
		EclipseTouchpoint touchpoint = new EclipseTouchpoint();
		Properties profileProperties = new Properties();
		profileProperties.setProperty(IProfile.PROP_INSTALL_FOLDER, getTempFolder().toString());
		IProfile profile = createProfile("test", null, profileProperties);
		InstallableUnitOperand operand = new InstallableUnitOperand(null, createIU("test"));
		touchpoint.initializePhase(null, profile, "test", parameters);
		parameters.put("iu", operand.second());
		touchpoint.initializeOperand(profile, operand, parameters);
		Manipulator manipulator = (Manipulator) parameters.get(EclipseTouchpoint.PARM_MANIPULATOR);
		assertNotNull(manipulator);

		String value = "test";
		assertFalse(manipulator.getConfigData().getProperties().containsKey(SampleEclipseAction.ECLIPSE_SAMPLE));
		parameters.put(SampleEclipseAction.VALUE, "test");
		parameters = Collections.unmodifiableMap(parameters);

		SampleEclipseAction action = new SampleEclipseAction();
		action.execute(parameters);
		assertEquals("test", manipulator.getConfigData().getProperty(SampleEclipseAction.ECLIPSE_SAMPLE));
		action.undo(parameters);
		assertFalse(manipulator.getConfigData().getProperties().containsKey(SampleEclipseAction.ECLIPSE_SAMPLE));
	}
}
