/*******************************************************************************
 * Copyright (c) 2009 IBM Corporation and others. All rights reserved. This
 * program and the accompanying materials are made available under the terms of
 * the Eclipse Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.equinox.p2.eclipsecon.actions.test;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Properties;

import org.eclipse.equinox.internal.p2.engine.ActionManager;
import org.eclipse.equinox.internal.p2.engine.InstructionParser;
import org.eclipse.equinox.internal.p2.engine.ParameterizedProvisioningAction;
import org.eclipse.equinox.internal.p2.touchpoint.eclipse.EclipseTouchpoint;
import org.eclipse.equinox.internal.provisional.frameworkadmin.Manipulator;
import org.eclipse.equinox.internal.provisional.p2.engine.IProfile;
import org.eclipse.equinox.internal.provisional.p2.engine.InstallableUnitOperand;
import org.eclipse.equinox.internal.provisional.p2.engine.ProvisioningAction;
import org.eclipse.equinox.internal.provisional.p2.metadata.MetadataFactory;
import org.eclipse.equinox.p2.tests.AbstractProvisioningTest;
import org.eclipse.equinox.p2.eclipsecon.actions.SampleSystemOutAction;

public class SampleSystemOutActionTest extends AbstractProvisioningTest {

	public void testParseAction() {
		InstructionParser parser = new InstructionParser(new ActionManager());
		ProvisioningAction[] actions = parser.parseActions(MetadataFactory.createTouchpointInstruction("sample.SystemOutAction()", null), null);
		assertEquals(1, actions.length);
		ProvisioningAction action = actions[0];
		if (action instanceof ParameterizedProvisioningAction)
			action = ((ParameterizedProvisioningAction)action).getAction();		
		assertEquals(action.getClass(), SampleSystemOutAction.class);
	}
	
	public void testParseActionWithImports() {
		InstructionParser parser = new InstructionParser(new ActionManager());
		ProvisioningAction[] actions = parser.parseActions(MetadataFactory.createTouchpointInstruction("SystemOutAction()", "sample.SystemOutAction"), null);
		assertEquals(1, actions.length);
		ProvisioningAction action = actions[0];
		if (action instanceof ParameterizedProvisioningAction)
			action = ((ParameterizedProvisioningAction)action).getAction();		
		assertEquals(action.getClass(), SampleSystemOutAction.class);
	}
	
	public void testExecuteUndo() {
		Map parameters = new HashMap();
		Properties profileProperties = new Properties();
		profileProperties.setProperty(IProfile.PROP_INSTALL_FOLDER, getTempFolder().toString());
		IProfile profile = createProfile("test", null, profileProperties);
		InstallableUnitOperand operand = new InstallableUnitOperand(null, createIU("test"));
		parameters.put("iu", operand.second());

		parameters.put("value", "test successful");
		parameters = Collections.unmodifiableMap(parameters);
		
		SampleSystemOutAction action = new SampleSystemOutAction();
		assertTrue(action.execute(parameters).isOK());
		assertTrue(action.undo(parameters).isOK());
		
		Properties badParameters = new Properties();
		badParameters.putAll(parameters);
		badParameters.remove("value");
		assertFalse(action.execute(badParameters).isOK());
		assertFalse(action.undo(badParameters).isOK());
	}
	
}
